import { pluralize } from '@code-pushup/utils';
import { getTypeScriptDiagnostics, } from './ts-runner.js';
import { getIssueFromDiagnostic, tsCodeToAuditSlug } from './utils.js';
export function createRunnerFunction(options) {
    const { tsconfig, expectedAudits } = options;
    return async () => {
        const diagnostics = await getTypeScriptDiagnostics({ tsconfig });
        const result = diagnostics.reduce((acc, diag) => {
            const slug = tsCodeToAuditSlug(diag.code);
            const existingIssues = acc[slug]?.details?.issues ?? [];
            return {
                ...acc,
                [slug]: {
                    slug,
                    details: {
                        issues: [...existingIssues, getIssueFromDiagnostic(diag)],
                    },
                },
            };
        }, {});
        return expectedAudits.map(({ slug }) => {
            const { details } = result[slug] ?? {};
            const issues = details?.issues ?? [];
            return {
                slug,
                score: issues.length === 0 ? 1 : 0,
                value: issues.length,
                displayValue: `${issues.length} ${pluralize('issue', issues.length)}`,
                ...(issues.length > 0 ? { details } : {}),
            };
        });
    };
}
//# sourceMappingURL=runner.js.map